
# Slot: enables


holds between a physical entity and a process, where the physical entity executes the process

URI: [biolink:enables](https://w3id.org/biolink/vocab/enables)


## Domain and Range

[PhysicalEntity](PhysicalEntity.md) &#8594;  <sub>0..\*</sub> [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)

## Parents

 *  is_a: [participates in](participates_in.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002327 |

